@@ -2,8 +2,8 @@
 # Cura is released under the terms of the LGPLv3 or higher.
 
 
-from PyQt5.QtCore import QVariantAnimation, QEasingCurve
-from PyQt5.QtGui import QVector3D
+from PyQt6.QtCore import QVariantAnimation, QEasingCurve
+from PyQt6.QtGui import QVector3D
 
 from UM.Math.Vector import Vector
 
@@ -13,7 +13,7 @@ class CameraAnimation(QVariantAnimation):
         super().__init__(parent)
         self._camera_tool = None
         self.setDuration(300)
-        self.setEasingCurve(QEasingCurve.OutQuad)
+        self.setEasingCurve(QEasingCurve.Type.OutQuad)
 
     def setCameraTool(self, camera_tool):
         self._camera_tool = camera_tool
