@@ -3,7 +3,7 @@
 
 from typing import Optional, List
 
-from PyQt5.QtCore import pyqtProperty, pyqtSignal, pyqtSlot, QObject
+from PyQt6.QtCore import pyqtProperty, pyqtSignal, pyqtSlot, QObject
 
 from UM.Logger import Logger
 from UM.Preferences import Preferences
@@ -19,6 +19,8 @@ class SettingVisibilityPresetsModel(QObject):
     onItemsChanged = pyqtSignal()
     activePresetChanged = pyqtSignal()
 
+    Version = 2
+
     def __init__(self, preferences: Preferences, parent = None) -> None:
         super().__init__(parent)
 
@@ -31,7 +33,7 @@ class SettingVisibilityPresetsModel(QObject):
         if basic_item is not None:
             basic_visibile_settings = ";".join(basic_item.settings)
         else:
-            Logger.log("w", "Unable to find the basic visiblity preset.")
+            Logger.log("w", "Unable to find the basic visibility preset.")
             basic_visibile_settings = ""
 
         self._preferences = preferences
@@ -77,6 +79,10 @@ class SettingVisibilityPresetsModel(QObject):
 
             items.append(setting_visibility_preset)
 
+        # Add the "all" visibility:
+        all_setting_visibility_preset = SettingVisibilityPreset(preset_id = "all", name = "All", weight = 9001)
+        all_setting_visibility_preset.setSettings(list(CuraApplication.getInstance().getMachineManager().getAllSettingKeys()))
+        items.append(all_setting_visibility_preset)
         # Sort them on weight (and if that fails, use ID)
         items.sort(key = lambda k: (int(k.weight), k.presetId))
 
