@@ -1,4 +1,4 @@
-# Copyright (c) 2019 Ultimaker B.V.
+# Copyright (c) 2021 Ultimaker B.V.
 # Cura is released under the terms of the LGPLv3 or higher.
 
 import os
@@ -6,8 +6,8 @@ import urllib.parse
 import uuid
 from typing import Any, cast, Dict, List, TYPE_CHECKING, Union
 
-from PyQt5.QtCore import QObject, QUrl
-from PyQt5.QtWidgets import QMessageBox
+from PyQt6.QtCore import QObject, QUrl
+from PyQt6.QtWidgets import QMessageBox
 
 from UM.i18n import i18nCatalog
 from UM.FlameProfiler import pyqtSlot
@@ -23,6 +23,8 @@ from UM.Settings.InstanceContainer import InstanceContainer
 
 import cura.CuraApplication
 from cura.Machines.ContainerTree import ContainerTree
+from cura.Settings.ExtruderStack import ExtruderStack
+from cura.Settings.GlobalStack import GlobalStack
 
 if TYPE_CHECKING:
     from cura.CuraApplication import CuraApplication
@@ -33,21 +35,23 @@ if TYPE_CHECKING:
 catalog = i18nCatalog("cura")
 
 
-##  Manager class that contains common actions to deal with containers in Cura.
-#
-#   This is primarily intended as a class to be able to perform certain actions
-#   from within QML. We want to be able to trigger things like removing a container
-#   when a certain action happens. This can be done through this class.
 class ContainerManager(QObject):
+    """Manager class that contains common actions to deal with containers in Cura.
+
+    This is primarily intended as a class to be able to perform certain actions
+    from within QML. We want to be able to trigger things like removing a container
+    when a certain action happens. This can be done through this class.
+    """
+
 
     def __init__(self, application: "CuraApplication") -> None:
         if ContainerManager.__instance is not None:
             raise RuntimeError("Try to create singleton '%s' more than once" % self.__class__.__name__)
-        ContainerManager.__instance = self
         try:
             super().__init__(parent = application)
         except TypeError:
             super().__init__()
+        ContainerManager.__instance = self
 
         self._container_name_filters = {}  # type: Dict[str, Dict[str, Any]]
 
@@ -67,21 +71,23 @@ class ContainerManager(QObject):
             return ""
         return str(result)
 
-    ##  Set a metadata entry of the specified container.
-    #
-    #   This will set the specified entry of the container's metadata to the specified
-    #   value. Note that entries containing dictionaries can have their entries changed
-    #   by using "/" as a separator. For example, to change an entry "foo" in a
-    #   dictionary entry "bar", you can specify "bar/foo" as entry name.
-    #
-    #   \param container_node \type{ContainerNode}
-    #   \param entry_name \type{str} The name of the metadata entry to change.
-    #   \param entry_value The new value of the entry.
-    #
-    #  TODO: This is ONLY used by MaterialView for material containers. Maybe refactor this.
-    #  Update: In order for QML to use objects and sub objects, those (sub) objects must all be QObject. Is that what we want?
     @pyqtSlot("QVariant", str, str)
     def setContainerMetaDataEntry(self, container_node: "ContainerNode", entry_name: str, entry_value: str) -> bool:
+        """Set a metadata entry of the specified container.
+
+        This will set the specified entry of the container's metadata to the specified
+        value. Note that entries containing dictionaries can have their entries changed
+        by using "/" as a separator. For example, to change an entry "foo" in a
+        dictionary entry "bar", you can specify "bar/foo" as entry name.
+
+        :param container_node: :type{ContainerNode}
+        :param entry_name: :type{str} The name of the metadata entry to change.
+        :param entry_value: The new value of the entry.
+
+        TODO: This is ONLY used by MaterialView for material containers. Maybe refactor this.
+        Update: In order for QML to use objects and sub objects, those (sub) objects must all be QObject. Is that what we want?
+        """
+
         if container_node.container is None:
             Logger.log("w", "Container node {0} doesn't have a container.".format(container_node.container_id))
             return False
@@ -118,24 +124,28 @@ class ContainerManager(QObject):
         root_material.setMetaDataEntry(entry_name, entry_value)
         if sub_item_changed: #If it was only a sub-item that has changed then the setMetaDataEntry won't correctly notice that something changed, and we must manually signal that the metadata changed.
             root_material.metaDataChanged.emit(root_material)
+
+        cura.CuraApplication.CuraApplication.getInstance().getMachineManager().updateUponMaterialMetadataChange()
         return True
 
     @pyqtSlot(str, result = str)
     def makeUniqueName(self, original_name: str) -> str:
         return cura.CuraApplication.CuraApplication.getInstance().getContainerRegistry().uniqueName(original_name)
 
-    ##  Get a list of string that can be used as name filters for a Qt File Dialog
-    #
-    #   This will go through the list of available container types and generate a list of strings
-    #   out of that. The strings are formatted as "description (*.extension)" and can be directly
-    #   passed to a nameFilters property of a Qt File Dialog.
-    #
-    #   \param type_name Which types of containers to list. These types correspond to the "type"
-    #                    key of the plugin metadata.
-    #
-    #   \return A string list with name filters.
     @pyqtSlot(str, result = "QStringList")
     def getContainerNameFilters(self, type_name: str) -> List[str]:
+        """Get a list of string that can be used as name filters for a Qt File Dialog
+
+        This will go through the list of available container types and generate a list of strings
+        out of that. The strings are formatted as "description (*.extension)" and can be directly
+        passed to a nameFilters property of a Qt File Dialog.
+
+        :param type_name: Which types of containers to list. These types correspond to the "type"
+            key of the plugin metadata.
+
+        :return: A string list with name filters.
+        """
+
         if not self._container_name_filters:
             self._updateContainerNameFilters()
 
@@ -147,17 +157,18 @@ class ContainerManager(QObject):
         filters.append("All Files (*)")
         return filters
 
-    ##  Export a container to a file
-    #
-    #   \param container_id The ID of the container to export
-    #   \param file_type The type of file to save as. Should be in the form of "description (*.extension, *.ext)"
-    #   \param file_url_or_string The URL where to save the file.
-    #
-    #   \return A dictionary containing a key "status" with a status code and a key "message" with a message
-    #           explaining the status.
-    #           The status code can be one of "error", "cancelled", "success"
     @pyqtSlot(str, str, QUrl, result = "QVariantMap")
     def exportContainer(self, container_id: str, file_type: str, file_url_or_string: Union[QUrl, str]) -> Dict[str, str]:
+        """Export a container to a file
+
+        :param container_id: The ID of the container to export
+        :param file_type: The type of file to save as. Should be in the form of "description (*.extension, *.ext)"
+        :param file_url_or_string: The URL where to save the file.
+
+        :return: A dictionary containing a key "status" with a status code and a key "message" with a message
+        explaining the status. The status code can be one of "error", "cancelled", "success"
+        """
+
         if not container_id or not file_type or not file_url_or_string:
             return {"status": "error", "message": "Invalid arguments"}
 
@@ -195,7 +206,7 @@ class ContainerManager(QObject):
             if os.path.exists(file_url):
                 result = QMessageBox.question(None, catalog.i18nc("@title:window", "File Already Exists"),
                                               catalog.i18nc("@label Don't translate the XML tag <filename>!", "The file <filename>{0}</filename> already exists. Are you sure you want to overwrite it?").format(file_url))
-                if result == QMessageBox.No:
+                if result == QMessageBox.StandardButton.No:
                     return {"status": "cancelled", "message": "User cancelled"}
 
         try:
@@ -206,19 +217,25 @@ class ContainerManager(QObject):
         if contents is None:
             return {"status": "error", "message": "Serialization returned None. Unable to write to file"}
 
-        with SaveFile(file_url, "w") as f:
-            f.write(contents)
+        try:
+            with SaveFile(file_url, "w") as f:
+                f.write(contents)
+        except OSError:
+            return {"status": "error", "message": "Unable to write to this location.", "path": file_url}
 
+        Logger.info("Successfully exported container to {path}".format(path = file_url))
         return {"status": "success", "message": "Successfully exported container", "path": file_url}
 
-    ##  Imports a profile from a file
-    #
-    #   \param file_url A URL that points to the file to import.
-    #
-    #   \return \type{Dict} dict with a 'status' key containing the string 'success' or 'error', and a 'message' key
-    #       containing a message for the user
     @pyqtSlot(QUrl, result = "QVariantMap")
     def importMaterialContainer(self, file_url_or_string: Union[QUrl, str]) -> Dict[str, str]:
+        """Imports a profile from a file
+
+        :param file_url: A URL that points to the file to import.
+
+        :return: :type{Dict} dict with a 'status' key containing the string 'success' or 'error', and a 'message' key
+            containing a message for the user
+        """
+
         if not file_url_or_string:
             return {"status": "error", "message": "Invalid path"}
 
@@ -226,6 +243,7 @@ class ContainerManager(QObject):
             file_url = file_url_or_string.toLocalFile()
         else:
             file_url = file_url_or_string
+        Logger.info(f"Importing material from {file_url}")
 
         if not file_url or not os.path.exists(file_url):
             return {"status": "error", "message": "Invalid path"}
@@ -239,6 +257,8 @@ class ContainerManager(QObject):
         container_type = container_registry.getContainerForMimeType(mime_type)
         if not container_type:
             return {"status": "error", "message": "Could not find a container to handle the specified file."}
+        if not issubclass(container_type, InstanceContainer):
+            return {"status": "error", "message": "This is not a material container, but another type of file."}
 
         container_id = urllib.parse.unquote_plus(mime_type.stripExtension(os.path.basename(file_url)))
         container_id = container_registry.uniqueName(container_id)
@@ -247,7 +267,7 @@ class ContainerManager(QObject):
 
         try:
             with open(file_url, "rt", encoding = "utf-8") as f:
-                container.deserialize(f.read())
+                container.deserialize(f.read(), file_url)
         except PermissionError:
             return {"status": "error", "message": "Permission denied when trying to read the file."}
         except ContainerFormatError:
@@ -261,14 +281,16 @@ class ContainerManager(QObject):
 
         return {"status": "success", "message": "Successfully imported container {0}".format(container.getName())}
 
-    ##  Update the current active quality changes container with the settings from the user container.
-    #
-    #   This will go through the active global stack and all active extruder stacks and merge the changes from the user
-    #   container into the quality_changes container. After that, the user container is cleared.
-    #
-    #   \return \type{bool} True if successful, False if not.
     @pyqtSlot(result = bool)
     def updateQualityChanges(self) -> bool:
+        """Update the current active quality changes container with the settings from the user container.
+
+        This will go through the active global stack and all active extruder stacks and merge the changes from the user
+        container into the quality_changes container. After that, the user container is cleared.
+
+        :return: :type{bool} True if successful, False if not.
+        """
+
         application = cura.CuraApplication.CuraApplication.getInstance()
         global_stack = application.getMachineManager().activeMachine
         if not global_stack:
@@ -278,7 +300,7 @@ class ContainerManager(QObject):
 
         current_quality_changes_name = global_stack.qualityChanges.getName()
         current_quality_type = global_stack.quality.getMetaDataEntry("quality_type")
-        extruder_stacks = list(global_stack.extruders.values())
+        extruder_stacks = global_stack.extruderList
         container_registry = cura.CuraApplication.CuraApplication.getInstance().getContainerRegistry()
         machine_definition_id = ContainerTree.getInstance().machines[global_stack.definition.getId()].quality_definition
         for stack in [global_stack] + extruder_stacks:
@@ -299,7 +321,7 @@ class ContainerManager(QObject):
                 stack.qualityChanges = quality_changes
 
             if not quality_changes or container_registry.isReadOnly(quality_changes.getId()):
-                Logger.log("e", "Could not update quality of a nonexistant or read only quality profile in stack %s", stack.getId())
+                Logger.log("e", "Could not update quality of a nonexistent or read only quality profile in stack %s", stack.getId())
                 continue
 
             self._performMerge(quality_changes, stack.getTop())
@@ -308,9 +330,10 @@ class ContainerManager(QObject):
 
         return True
 
-    ##  Clear the top-most (user) containers of the active stacks.
     @pyqtSlot()
     def clearUserContainers(self) -> None:
+        """Clear the top-most (user) containers of the active stacks."""
+
         machine_manager = cura.CuraApplication.CuraApplication.getInstance().getMachineManager()
         machine_manager.blurSettings.emit()
 
@@ -318,8 +341,7 @@ class ContainerManager(QObject):
 
         # Go through global and extruder stacks and clear their topmost container (the user settings).
         global_stack = machine_manager.activeMachine
-        extruder_stacks = list(global_stack.extruders.values())
-        for stack in [global_stack] + extruder_stacks:
+        for stack in [global_stack] + global_stack.extruderList:
             container = stack.userChanges
             container.clear()
             send_emits_containers.append(container)
@@ -327,28 +349,34 @@ class ContainerManager(QObject):
         # user changes are possibly added to make the current setup match the current enabled extruders
         machine_manager.correctExtruderSettings()
 
+        # The Print Sequence should be changed to match the current setup
+        machine_manager.correctPrintSequence()
+
         for container in send_emits_containers:
             container.sendPostponedEmits()
 
-    ##  Get a list of materials that have the same GUID as the reference material
-    #
-    #   \param material_node The node representing the material for which to get
-    #   the same GUID.
-    #   \param exclude_self Whether to include the name of the material you
-    #   provided.
-    #   \return A list of names of materials with the same GUID.
     @pyqtSlot("QVariant", bool, result = "QStringList")
     def getLinkedMaterials(self, material_node: "MaterialNode", exclude_self: bool = False) -> List[str]:
+        """Get a list of materials that have the same GUID as the reference material
+
+        :param material_node: The node representing the material for which to get
+            the same GUID.
+        :param exclude_self: Whether to include the name of the material you provided.
+        :return: A list of names of materials with the same GUID.
+        """
+
         same_guid = ContainerRegistry.getInstance().findInstanceContainersMetadata(GUID = material_node.guid)
         if exclude_self:
             return list({meta["name"] for meta in same_guid if meta["base_file"] != material_node.base_file})
         else:
             return list({meta["name"] for meta in same_guid})
 
-    ##  Unlink a material from all other materials by creating a new GUID
-    #   \param material_id \type{str} the id of the material to create a new GUID for.
     @pyqtSlot("QVariant")
     def unlinkMaterial(self, material_node: "MaterialNode") -> None:
+        """Unlink a material from all other materials by creating a new GUID
+
+        :param material_id: :type{str} the id of the material to create a new GUID for.
+        """
         # Get the material group
         if material_node.container is None:  # Failed to lazy-load this container.
             return
@@ -382,7 +410,7 @@ class ContainerManager(QObject):
         container_registry = cura.CuraApplication.CuraApplication.getInstance().getContainerRegistry()
         for plugin_id, container_type in container_registry.getContainerTypes():
             # Ignore default container types since those are not plugins
-            if container_type in (InstanceContainer, ContainerStack, DefinitionContainer):
+            if container_type in (InstanceContainer, ContainerStack, DefinitionContainer, GlobalStack, ExtruderStack):
                 continue
 
             serialize_type = ""
@@ -423,9 +451,10 @@ class ContainerManager(QObject):
             name_filter = "{0} ({1})".format(mime_type.comment, suffix_list)
             self._container_name_filters[name_filter] = entry
 
-    ##  Import single profile, file_url does not have to end with curaprofile
     @pyqtSlot(QUrl, result = "QVariantMap")
     def importProfile(self, file_url: QUrl) -> Dict[str, str]:
+        """Import single profile, file_url does not have to end with curaprofile"""
+
         if not file_url.isValid():
             return {"status": "error", "message": catalog.i18nc("@info:status", "Invalid file URL:") + " " + str(file_url)}
         path = file_url.toLocalFile()
