@@ -1,4 +1,4 @@
-# Copyright (c) 2021 Ultimaker B.V.
+# Copyright (c) 2022 Ultimaker B.V.
 # Cura is released under the terms of the LGPLv3 or higher.
 
 import math
@@ -24,13 +24,15 @@ from cura.Settings.ExtruderManager import ExtruderManager
 
 catalog = i18nCatalog("cura")
 
-PositionOptional = NamedTuple("Position", [("x", Optional[float]), ("y", Optional[float]), ("z", Optional[float]), ("f", Optional[float]), ("e", Optional[float])])
+PositionOptional = NamedTuple("PositionOptional", [("x", Optional[float]), ("y", Optional[float]), ("z", Optional[float]), ("f", Optional[float]), ("e", Optional[float])])
 Position = NamedTuple("Position", [("x", float), ("y", float), ("z", float), ("f", float), ("e", List[float])])
 
 
 class FlavorParser:
     """This parser is intended to interpret the common firmware codes among all the different flavors"""
 
+    MAX_EXTRUDER_COUNT = 16
+
     def __init__(self) -> None:
         CuraApplication.getInstance().hideMessageSignal.connect(self._onHideMessage)
         self._cancelled = False
@@ -53,7 +55,7 @@ class FlavorParser:
 
     def _clearValues(self) -> None:
         self._extruder_number = 0
-        self._extrusion_length_offset = [0] # type: List[float]
+        self._extrusion_length_offset = [0] * self.MAX_EXTRUDER_COUNT # type: List[float]
         self._layer_type = LayerPolygon.Inset0Type
         self._layer_number = 0
         self._previous_z = 0 # type: float
@@ -283,8 +285,9 @@ class FlavorParser:
             return func(position, params, path)
         return position
 
-    def processTCode(self, T: int, line: str, position: Position, path: List[List[Union[float, int]]]) -> Position:
+    def processTCode(self, global_stack, T: int, line: str, position: Position, path: List[List[Union[float, int]]]) -> Position:
         self._extruder_number = T
+        self._filament_diameter = global_stack.extruderList[self._extruder_number].getProperty("material_diameter", "value")
         if self._extruder_number + 1 > len(position.e):
             self._extrusion_length_offset.extend([0] * (self._extruder_number - len(position.e) + 1))
             position.e.extend([0] * (self._extruder_number - len(position.e) + 1))
@@ -354,7 +357,7 @@ class FlavorParser:
 
         Logger.log("d", "Parsing g-code...")
 
-        current_position = Position(0, 0, 0, 0, [0])
+        current_position = Position(0, 0, 0, 0, [0] * self.MAX_EXTRUDER_COUNT)
         current_path = [] #type: List[List[float]]
         min_layer_number = 0
         negative_layers = 0
@@ -444,7 +447,7 @@ class FlavorParser:
                     # When changing tool, store the end point of the previous path, then process the code and finally
                     # add another point with the new position of the head.
                     current_path.append([current_position.x, current_position.y, current_position.z, current_position.f, current_position.e[self._extruder_number], LayerPolygon.MoveCombingType])
-                    current_position = self.processTCode(T, line, current_position, current_path)
+                    current_position = self.processTCode(global_stack, T, line, current_position, current_path)
                     current_path.append([current_position.x, current_position.y, current_position.z, current_position.f, current_position.e[self._extruder_number], LayerPolygon.MoveCombingType])
 
             if line.startswith("M"):
