@@ -1,10 +1,12 @@
-# Copyright (c) 2015 Ultimaker B.V.
+# Copyright (c) 2020 Ultimaker B.V.
 # Cura is released under the terms of the LGPLv3 or higher.
 
 import numpy
 
-from PyQt5.QtGui import QImage, qRed, qGreen, qBlue
-from PyQt5.QtCore import Qt
+import math
+
+from PyQt6.QtGui import QImage, qRed, qGreen, qBlue, qAlpha
+from PyQt6.QtCore import Qt
 
 from UM.Mesh.MeshReader import MeshReader
 from UM.Mesh.MeshBuilder import MeshBuilder
@@ -46,15 +48,12 @@ class ImageReader(MeshReader):
 
     def _read(self, file_name):
         size = max(self._ui.getWidth(), self._ui.getDepth())
-        return self._generateSceneNode(file_name, size, self._ui.peak_height, self._ui.base_height, self._ui.smoothing, 512, self._ui.lighter_is_higher)
+        return self._generateSceneNode(file_name, size, self._ui.peak_height, self._ui.base_height, self._ui.smoothing, 512, self._ui.lighter_is_higher, self._ui.use_transparency_model, self._ui.transmittance_1mm)
 
-    def _generateSceneNode(self, file_name, xz_size, peak_height, base_height, blur_iterations, max_size, lighter_is_higher):
+    def _generateSceneNode(self, file_name, xz_size, height_from_base, base_height, blur_iterations, max_size, lighter_is_higher, use_transparency_model, transmittance_1mm):
         scene_node = SceneNode()
-
         mesh = MeshBuilder()
-
         img = QImage(file_name)
-
         if img.isNull():
             Logger.log("e", "Image is corrupt.")
             return None
@@ -64,13 +63,14 @@ class ImageReader(MeshReader):
         aspect = height / width
 
         if img.width() < 2 or img.height() < 2:
-            img = img.scaled(width, height, Qt.IgnoreAspectRatio)
+            img = img.scaled(width, height, Qt.AspectRatioMode.IgnoreAspectRatio)
 
+        height_from_base = max(height_from_base, 0)
         base_height = max(base_height, 0)
-        peak_height = max(peak_height, -base_height)
+
 
         xz_size = max(xz_size, 1)
-        scale_vector = Vector(xz_size, peak_height, xz_size)
+        scale_vector = Vector(xz_size, height_from_base, xz_size)
 
         if width > height:
             scale_vector = scale_vector.set(z=scale_vector.z * aspect)
@@ -84,31 +84,33 @@ class ImageReader(MeshReader):
 
             width = int(max(round(width * scale_factor), 2))
             height = int(max(round(height * scale_factor), 2))
-            img = img.scaled(width, height, Qt.IgnoreAspectRatio)
+            img = img.scaled(width, height, Qt.AspectRatioMode.IgnoreAspectRatio)
 
         width_minus_one = width - 1
         height_minus_one = height - 1
 
         Job.yieldThread()
 
-        texel_width = 1.0 / (width_minus_one) * scale_vector.x
-        texel_height = 1.0 / (height_minus_one) * scale_vector.z
+        texel_width = 1.0 / width_minus_one * scale_vector.x
+        texel_height = 1.0 / height_minus_one * scale_vector.z
 
-        height_data = numpy.zeros((height, width), dtype=numpy.float32)
+        height_data = numpy.zeros((height, width), dtype = numpy.float32)
 
         for x in range(0, width):
             for y in range(0, height):
                 qrgb = img.pixel(x, y)
-                avg = float(qRed(qrgb) + qGreen(qrgb) + qBlue(qrgb)) / (3 * 255)
-                height_data[y, x] = avg
+                if use_transparency_model:
+                    height_data[y, x] = (0.299 * math.pow(qRed(qrgb) / 255.0, 2.2) + 0.587 * math.pow(qGreen(qrgb) / 255.0, 2.2) + 0.114 * math.pow(qBlue(qrgb) / 255.0, 2.2))
+                else:
+                    height_data[y, x] = (0.212655 * qRed(qrgb) + 0.715158 * qGreen(qrgb) + 0.072187 * qBlue(qrgb)) / 255 # fast computation ignoring gamma and degamma
 
         Job.yieldThread()
 
-        if not lighter_is_higher:
+        if lighter_is_higher == use_transparency_model:
             height_data = 1 - height_data
 
         for _ in range(0, blur_iterations):
-            copy = numpy.pad(height_data, ((1, 1), (1, 1)), mode= "edge")
+            copy = numpy.pad(height_data, ((1, 1), (1, 1)), mode = "edge")
 
             height_data += copy[1:-1, 2:]
             height_data += copy[1:-1, :-2]
@@ -124,8 +126,20 @@ class ImageReader(MeshReader):
 
             Job.yieldThread()
 
-        height_data *= scale_vector.y
-        height_data += base_height
+        if use_transparency_model:
+            divisor = 1.0 / math.log(transmittance_1mm / 100.0) # log-base doesn't matter here. Precompute this value for faster computation of each pixel.
+            min_luminance = (transmittance_1mm / 100.0) ** height_from_base
+            for (y, x) in numpy.ndindex(height_data.shape):
+                mapped_luminance = min_luminance + (1.0 - min_luminance) * height_data[y, x]
+                height_data[y, x] = base_height + divisor * math.log(mapped_luminance) # use same base as a couple lines above this
+        else:
+            height_data *= scale_vector.y
+            height_data += base_height
+
+        if img.hasAlphaChannel():
+            for x in range(0, width):
+                for y in range(0, height):
+                    height_data[y, x] *= qAlpha(img.pixel(x, y)) / 255.0
 
         heightmap_face_count = 2 * height_minus_one * width_minus_one
         total_face_count = heightmap_face_count + (width_minus_one * 2) * (height_minus_one * 2) + 2
@@ -149,7 +163,7 @@ class ImageReader(MeshReader):
         offsetsz = numpy.array(offsetsz, numpy.float32).reshape(-1, 1) * texel_height
 
         # offsets for each texel quad
-        heightmap_vertex_offsets = numpy.concatenate([offsetsx, numpy.zeros((offsetsx.shape[0], offsetsx.shape[1]), dtype=numpy.float32), offsetsz], 1)
+        heightmap_vertex_offsets = numpy.concatenate([offsetsx, numpy.zeros((offsetsx.shape[0], offsetsx.shape[1]), dtype = numpy.float32), offsetsz], 1)
         heightmap_vertices += heightmap_vertex_offsets.repeat(6, 0).reshape(-1, 6, 3)
 
         # apply height data to y values
@@ -158,7 +172,7 @@ class ImageReader(MeshReader):
         heightmap_vertices[:, 2, 1] = heightmap_vertices[:, 3, 1] = height_data[1:, 1:].reshape(-1)
         heightmap_vertices[:, 4, 1] = height_data[:-1, 1:].reshape(-1)
 
-        heightmap_indices = numpy.array(numpy.mgrid[0:heightmap_face_count * 3], dtype=numpy.int32).reshape(-1, 3)
+        heightmap_indices = numpy.array(numpy.mgrid[0:heightmap_face_count * 3], dtype = numpy.int32).reshape(-1, 3)
 
         mesh._vertices[0:(heightmap_vertices.size // 3), :] = heightmap_vertices.reshape(-1, 3)
         mesh._indices[0:(heightmap_indices.size // 3), :] = heightmap_indices
@@ -207,7 +221,7 @@ class ImageReader(MeshReader):
             mesh.addFaceByPoints(geo_width, 0, y, geo_width, 0, ny, geo_width, he1, ny)
             mesh.addFaceByPoints(geo_width, he1, ny, geo_width, he0, y, geo_width, 0, y)
 
-        mesh.calculateNormals(fast=True)
+        mesh.calculateNormals(fast = True)
 
         scene_node.setMeshData(mesh.build())
 
