@@ -1,5 +1,6 @@
-# Copyright (c) 2016 Ultimaker B.V.
-# Uranium is released under the terms of the LGPLv3 or higher.
+# Copyright (c) 2021 Ultimaker B.V.
+# Cura is released under the terms of the LGPLv3 or higher.
+
 from UM.Logger import Logger
 from UM.Tool import Tool
 from UM.Scene.Selection import Selection
@@ -11,9 +12,11 @@ from UM.Settings.SettingInstance import SettingInstance
 from UM.Event import Event
 
 
-##  This tool allows the user to add & change settings per node in the scene.
-#   The settings per object are kept in a ContainerStack, which is linked to a node by decorator.
 class PerObjectSettingsTool(Tool):
+    """This tool allows the user to add & change settings per node in the scene.
+
+    The settings per object are kept in a ContainerStack, which is linked to a node by decorator.
+    """
     def __init__(self):
         super().__init__()
         self._model = None
@@ -22,14 +25,13 @@ class PerObjectSettingsTool(Tool):
 
         self._multi_extrusion = False
         self._single_model_selected = False
+        self.visibility_handler = None
 
         Selection.selectionChanged.connect(self.propertyChanged)
-
         Application.getInstance().globalContainerStackChanged.connect(self._onGlobalContainerChanged)
         self._onGlobalContainerChanged()
         Selection.selectionChanged.connect(self._updateEnabled)
 
-
     def event(self, event):
         super().event(event)
         if event.type == Event.MousePressEvent and self._controller.getToolsEnabled():
@@ -48,27 +50,33 @@ class PerObjectSettingsTool(Tool):
         except AttributeError:
             return ""
 
-    ##  Gets the active extruder of the currently selected object.
-    #
-    #   \return The active extruder of the currently selected object.
     def getSelectedActiveExtruder(self):
+        """Gets the active extruder of the currently selected object.
+
+        :return: The active extruder of the currently selected object.
+        """
+
         selected_object = Selection.getSelectedObject(0)
         return selected_object.callDecoration("getActiveExtruder")
 
-    ##  Changes the active extruder of the currently selected object.
-    #
-    #   \param extruder_stack_id The ID of the extruder to print the currently
-    #   selected object with.
     def setSelectedActiveExtruder(self, extruder_stack_id):
+        """Changes the active extruder of the currently selected object.
+
+        :param extruder_stack_id: The ID of the extruder to print the currently
+        selected object with.
+        """
+
         selected_object = Selection.getSelectedObject(0)
         stack = selected_object.callDecoration("getStack") #Don't try to get the active extruder since it may be None anyway.
         if not stack:
             selected_object.addDecorator(SettingOverrideDecorator())
         selected_object.callDecoration("setActiveExtruder", extruder_stack_id)
 
-    ## Returns True when the mesh_type was changed, False when current mesh_type == mesh_type
     def setMeshType(self, mesh_type: str) -> bool:
-        if self.getMeshType() == mesh_type:
+        """Returns True when the mesh_type was changed, False when current mesh_type == mesh_type"""
+
+        old_mesh_type = self.getMeshType()
+        if old_mesh_type == mesh_type:
             return False
 
         selected_object = Selection.getSelectedObject(0)
@@ -81,6 +89,7 @@ class PerObjectSettingsTool(Tool):
             selected_object.addDecorator(SettingOverrideDecorator())
             stack = selected_object.callDecoration("getStack")
 
+        settings_visibility_changed = False
         settings = stack.getTop()
         for property_key in ["infill_mesh", "cutting_mesh", "support_mesh", "anti_overhang_mesh"]:
             if property_key != mesh_type:
@@ -94,6 +103,33 @@ class PerObjectSettingsTool(Tool):
                     new_instance.resetState()  # Ensure that the state is not seen as a user state.
                     settings.addInstance(new_instance)
 
+        # Override some settings to ensure that the infill mesh by default adds no skin or walls. Or remove them if not an infill mesh.
+        specialized_settings = {
+            "top_bottom_thickness": 0,
+            "top_thickness": "=top_bottom_thickness",
+            "bottom_thickness": "=top_bottom_thickness",
+            "top_layers": "=0 if infill_sparse_density == 100 else math.ceil(round(top_thickness / resolveOrValue('layer_height'), 4))",
+            "bottom_layers": "=0 if infill_sparse_density == 100 else math.ceil(round(bottom_thickness / resolveOrValue('layer_height'), 4))",
+            "wall_thickness": 0,
+            "wall_line_count": "=max(1, round((wall_thickness - wall_line_width_0) / wall_line_width_x) + 1) if wall_thickness != 0 else 0"
+        }
+        for property_key in specialized_settings:
+            if mesh_type == "infill_mesh":
+                if settings.getInstance(property_key) is None:
+                    definition = stack.getSettingDefinition(property_key)
+                    new_instance = SettingInstance(definition, settings)
+                    new_instance.setProperty("value", specialized_settings[property_key])
+                    new_instance.resetState()  # Ensure that the state is not seen as a user state.
+                    settings.addInstance(new_instance)
+                    settings_visibility_changed = True
+
+            elif old_mesh_type == "infill_mesh" and settings.getInstance(property_key) and property_key in specialized_settings:
+                settings.removeInstance(property_key)
+                settings_visibility_changed = True
+
+        if settings_visibility_changed:
+            self.visibility_handler.forceVisibilityChanged()
+
         self.propertyChanged.emit()
         return True
 
